@@ -4,7 +4,7 @@
 
 # [[[ HEADER ]]]
 use RPerl;
-package RPerl::Test::LiteralNumber::Package_34_Bad_00;
+package RPerl::Test::LiteralNumber::Package_36_Bad_00;
 use strict;
 use warnings;
 our $VERSION = 0.001_000;
@@ -13,8 +13,6 @@ our $VERSION = 0.001_000;
 ## no critic qw(ProhibitUselessNoCritic ProhibitMagicNumbers RequireCheckedSyscalls)  # USER DEFAULT 1: allow numeric values & print operator
 
 # [[[ SUBROUTINES ]]]
-our number $empty_sub = sub {
-    return --2.234_56;
-};
+sub empty_sub { { my number $RETURN_TYPE }; return --2.234_56; }
 
 1;    # end of package
