@@ -9,8 +9,6 @@ use strict;
 use warnings;
 our $VERSION = 0.001_000;
 
-our number $empty_sub = sub {
-    return 23_456._2;
-};
+sub empty_sub { { my number $RETURN_TYPE }; return 23_456._2; }
 
 1;    # end of package
