@@ -6,6 +6,6 @@ use warnings;
 our $VERSION = 0.001_000;
 
 # [[[ SUBROUTINES ]]]
-our string $empty_sub = sub { return "\n\nfoo\n\nbar\n\n"; };
+sub empty_sub { { my string $RETURN_TYPE }; return "\n\nfoo\n\nbar\n\n"; }
 
 1;    # end of package
