@@ -6,6 +6,6 @@ use warnings;
 our $VERSION = 0.001_000;
 
 # [[[ SUBROUTINES ]]]
-our string $empty_sub = sub { return 'f'; };
+sub empty_sub { { my string $RETURN_TYPE }; return 'f'; }
 
 1;    # end of package
